import type { Bud } from '@roots/bud-framework';
import { Extension } from '@roots/bud-framework/extension';
import type { LoaderOptions, Registry } from './types.js';
/**
 * Babel configuration
 */
export default class BabelExtension extends Extension {
    /**
     * Boolean representing if project has a babel config file
     */
    get overridenByProjectConfigFile(): boolean;
    /**
     * Config file accessor
     */
    get configFile(): Record<string, any>;
    /**
     * Babel configuration options (if overridden by project config file)
     */
    configFileOptions: Record<string, any> | undefined;
    /**
     * Cache directory
     */
    get cacheDirectory(): LoaderOptions[`cacheDirectory`];
    /**
     * Babel env
     */
    env: LoaderOptions[`env`];
    /**
     * Get babel env value
     */
    getEnv(): LoaderOptions[`env`];
    /**
     * Set babel env value
     *
     * @param env - Babel env
     * @returns this
     */
    setEnv(env: LoaderOptions[`env`]): this;
    /**
     * Plugins registry
     */
    plugins: Registry;
    /**
     * Presets registry
     */
    presets: Registry;
    /**
     * Root directory
     */
    get root(): string;
    /**
     * Loader options
     *
     * @readonly
     */
    get loaderOptions(): LoaderOptions;
    /**
     * {@link Extension.register}
     */
    register({ build, hooks }: Bud): Promise<void>;
    /**
     * Set a babel preset
     */
    setPreset(name: string, preset?: [string, any] | string): this;
    /**
     * Set babel presets
     */
    setPresets(presets: {
        [key: string]: [string, any] | string;
    }): this;
    /**
     * Remove a babel preset
     */
    unsetPreset(preset: string): this;
    /**
     * Set options on a babel preset
     */
    setPresetOptions(preset: string, options: any): this;
    /**
     * Set a babel plugin
     */
    setPlugin(name: string | [any, any], plugin?: [any, any] | string): this;
    /**
     * Set babel presets
     */
    setPlugins(plugins: {
        [key: string]: [any, any] | string;
    }): this;
    /**
     * Remove a babel plugin
     */
    unsetPlugin(plugin: string): this;
    /**
     * Set options on a babel plugin
     */
    setPluginOptions(plugin: string, options: any): this;
}
